<?php

declare(strict_types=1);

namespace Drupal\content_commander_test\ContentCommander;

use Drupal\content_commander\Attribute\DependsOn;
use Drupal\content_commander\ContentContext;
use Drupal\content_commander\ContentInterface;
use Drupal\content_commander\ContentTrait;
use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\entity_test\Entity\EntityTest;
use Symfony\Component\Console\Attribute\AsCommand;

/**
 * Test content where enum values are arbitrary, UUIDs returned by a method.
 */
#[AsCommand('content-commander-test:test')]
enum CcTestContent: string implements ContentInterface {

  use ContentTrait;

  case Content1 = 'Foo1';

  #[DependsOn(self::Content1)]
  case Content2 = 'Foo2';

  #[DependsOn(self::Content2)]
  case Content3 = 'Foo3';

  #[DependsOn(self::Content2)]
  case Content4 = 'Foo4';

  #[DependsOn(self::Content2), DependsOn(self::Content4)]
  case Content5 = 'Foo5';

  public function createContent(ContentContext $contentContext, ContentEntityInterface $entity): void {
    \assert($entity instanceof EntityTest);
    (match ($this) {
      self::Content1 => static function (EntityTest $entity): void {
        $entity->setName('Foo 1');
      },
      self::Content2 => static function (EntityTest $entity) use ($contentContext): void {
        $dep1 = $contentContext->getDependency(self::Content1);
        $entity->setName(\sprintf('Foo 2 (%s)', \implode(', ', [$dep1->label()])));
      },
      self::Content3 => static function (EntityTest $entity) use ($contentContext): void {
        $dep1 = $contentContext->getDependency(self::Content2);
        $entity->setName(\sprintf('Foo 3 (%s)', \implode(', ', [$dep1->label()])));
      },
      self::Content4 => static function (EntityTest $entity) use ($contentContext): void {
        $dep1 = $contentContext->getDependency(self::Content2);
        $entity->setName(\sprintf('Foo 4 (%s)', \implode(', ', [$dep1->label()])));
      },
      self::Content5 => static function (EntityTest $entity) use ($contentContext): void {
        $dep1 = $contentContext->getDependency(self::Content2);
        $dep2 = $contentContext->getDependency(self::Content4);
        $entity->setName(\sprintf('Foo 5 (%s)', \implode(', ', [$dep1->label(), $dep2->label()])));
      },
    })($entity);
  }

  public function uuid(): ?string {
    return match ($this) {
      self::Content1 => 'abcaaaaa-aaaa-aaaa-aaaa-000000000001',
      self::Content2 => 'abcaaaaa-aaaa-aaaa-aaaa-000000000002',
      self::Content3 => 'abcaaaaa-aaaa-aaaa-aaaa-000000000003',
      self::Content4 => 'abcaaaaa-aaaa-aaaa-aaaa-000000000004',
      self::Content5 => 'abcaaaaa-aaaa-aaaa-aaaa-000000000005',
    };
  }

  public function entityClass(): string {
    return EntityTest::class;
  }

}
